@@ -107,19 +107,18 @@ class ExternOutput (BufferBase):
     files = np.array(self._files, dtype=object)
     # Only construct graphs for records that will ultimately appear in the
     # dask objects.
-    active = self._headers['dltf'] == 0
+    active = self._headers['selected'] == True
     nrecs = np.sum(active)
     filenames = files[self._headers['file_id'][active]]
-    graphs = zip([_read_block]*nrecs, filenames, self._headers['swa'][active]*8-8, self._headers['lng'][active]*4)
+    graphs = zip([_read_block]*nrecs, filenames, self._headers['address'][active], self._headers['length'][active])
     graphs = zip([self._decode]*nrecs, graphs, np.where(active)[0])
-    graphs = zip([np.transpose]*nrecs, graphs)
     g = np.empty(nrecs, dtype=object)
     g[:] = list(graphs)
     out = np.empty(self._nrecs, dtype=object)
     out[active] = g
     return out
 
-  def _iter_dask (self):
+  def _iter_dask (self, include_coords=True):
     """
     Iterate over all the variables, and convert to dask arrays.
     """
@@ -133,6 +132,9 @@ class ExternOutput (BufferBase):
     graphs = self._graphs()
     self._makevars()
     for var in self._iter_objects():
+      if not include_coords:
+        if var not in self._varlist:
+          continue
       if not isinstance(var,(_iter_type,_chunk_type)):
         yield var
         continue
@@ -220,6 +222,41 @@ class ExternOutput (BufferBase):
 
     return out
 
+  def to_xarray_list (self):
+    """
+    Similar to the to_xarray method, but returns a list of xarray Datasets,
+    one for each variable, instead of a single Dataset object.
+    Could be useful for case where the dimension names are non-unique, to avoid
+    name clobbering (in conjunction with unique_names initialization option).
+    E.g.,
+    Buffer("filename",unique_names=False).to_xarray_list()
+    """
+    from collections import OrderedDict
+    import xarray as xr
+    from fstd2nc.mixins import _axis_type
+    out_list = []
+    for var in self._iter_dask(include_coords=False):
+      if not hasattr(var,'array'): continue
+      out = OrderedDict()
+      out[var.name] = xr.DataArray(data=var.array, dims=var.dims, name=var.name, attrs=var.atts)
+      for extra in self._iter_objects(var):
+        if not hasattr(extra,'array'): continue
+        out[extra.name] = xr.DataArray(data=extra.array, dims=extra.dims, name=extra.name, attrs=extra.atts)
+      # Preserve chunking information for writing to netCDF4.
+      if hasattr(var.array,'chunks'):
+        chunk_shape = [c[0] for c in var.array.chunks]
+        out[var.name].encoding['chunksizes'] = chunk_shape
+        out[var.name].encoding['original_shape'] = out[var.name].shape
+      # Construct the Dataset from the variable.
+      out = xr.Dataset(out)
+      # Decode CF metadata
+      out = xr.conventions.decode_cf(out)
+      # Make the time dimension unlimited when writing to netCDF.
+      out.encoding['unlimited_dims'] = ('time',)
+      out_list.append(out)
+
+    return out_list
+
   def to_iris (self):
     """
     Create an iris interface for the RPN data.
@@ -336,6 +373,10 @@ class ExternInput (BufferBase):
     # Add other fields that may be needed.
     if 'dltf' not in headers:
       headers['dltf'] = np.zeros(len(headers['nomvar']), dtype='int32')
+      # We don't have file address info, so mark this as 'None' in case
+      # any subroutine is looking for this info.
+      headers['address'] = np.empty(len(headers['nomvar']), dtype=object)
+      headers['length'] = np.empty(len(headers['nomvar']), dtype=object)
     # Generate temporary file with target grid info.
     try: # Python 3
       grid_tmpdir = tempfile.TemporaryDirectory()
@@ -380,3 +421,20 @@ class ExternInput (BufferBase):
     # Otherwise, continue as usual.
     return super(ExternInput,self)._fstluk (rec_id, dtype, rank, dataArray)
 
+  # Handle external data for _decode method.
+  # In this case, the first argument is ignored (no file data was read).
+  def _decode (self, maybe_data, rec_id):
+    import numpy as np
+    # Check if there is custom data enabled for this Buffer.
+    if hasattr(self, '_extern_table'):
+      # Make sure we are looking for something in our list of records.
+      # (could be a key pointing into something else?)
+      if not isinstance(rec_id,dict):
+        # Extract the record info from the table.
+        rec = self._extern_table.iloc[rec_id].to_dict()
+        # Load the data (if delayed).
+        rec['d'] = np.asarray(rec['d'])
+        return rec['d'].T
+    # Otherwise, continue as usual.
+    return super(ExternInput,self)._decode (maybe_data, rec_id)
+
